@@ -4,7 +4,7 @@
  * radiusd.h	Structures, prototypes and global variables
  *		for the FreeRADIUS server.
  *
- * Version:	$Id: radiusd.h,v 1.261 2008/03/07 09:49:49 aland Exp $
+ * Version:	$Id: radiusd.h,v 1.263 2008/04/30 10:00:53 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  */
 
 #include <freeradius-devel/ident.h>
-RCSIDH(radiusd_h, "$Id: radiusd.h,v 1.261 2008/03/07 09:49:49 aland Exp $")
+RCSIDH(radiusd_h, "$Id: radiusd.h,v 1.263 2008/04/30 10:00:53 aland Exp $")
 
 #include <freeradius-devel/libradius.h>
 #include <freeradius-devel/radpaths.h>
@@ -89,6 +89,7 @@ typedef enum RAD_LISTEN_TYPE {
 	RAD_LISTEN_ACCT,
 	RAD_LISTEN_DETAIL,
 	RAD_LISTEN_VQP,
+	RAD_LISTEN_DHCP,
 	RAD_LISTEN_SNMP,
 	RAD_LISTEN_MAX
 } RAD_LISTEN_TYPE;
@@ -492,4 +493,5 @@ int radius_evaluate_condition(REQUEST *request, int modreturn, int depth,
 			      const char **ptr, int evaluate_it, int *presult);
 int radius_update_attrlist(REQUEST *request, CONF_SECTION *cs,
 			   VALUE_PAIR *input_vps, const char *name);
+void radius_pairmove(REQUEST *request, VALUE_PAIR **to, VALUE_PAIR *from);
 #endif /*RADIUSD_H*/
