@@ -1,7 +1,7 @@
 /*
  * radius.c	Functions to send/receive radius packets.
  *
- * Version:	$Id: radius.c,v 1.216 2008/02/05 15:07:17 aland Exp $
+ * Version:	$Id: radius.c,v 1.219 2008/04/11 09:55:02 aland Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,7 @@
  */
 
 #include	<freeradius-devel/ident.h>
-RCSID("$Id: radius.c,v 1.216 2008/02/05 15:07:17 aland Exp $")
+RCSID("$Id: radius.c,v 1.219 2008/04/11 09:55:02 aland Exp $")
 
 #include	<freeradius-devel/libradius.h>
 #include	<freeradius-devel/md5.h>
@@ -54,6 +54,7 @@ RCSID("$Id: radius.c,v 1.216 2008/02/05 15:07:17 aland Exp $")
  *	even if the end request is rejected.
  */
 int librad_max_attributes = 0;
+FILE *fr_log_fp = NULL;
 
 typedef struct radius_packet_t {
   uint8_t	code;
@@ -125,6 +126,22 @@ static const char *packet_codes[] = {
 };
 
 
+void fr_printf_log(const char *fmt, ...)
+{
+	va_list ap;
+
+	va_start(ap, fmt);
+	if ((librad_debug == 0) || !fr_log_fp) {
+		va_end(ap);
+		return;
+	}
+
+	vfprintf(fr_log_fp, fmt, ap);
+	va_end(ap);
+
+	return;
+}
+
 /*
  *	Wrapper for sendto which handles sendfromto, IPv6, and all
  *	possible combinations.
@@ -1421,7 +1438,7 @@ int rad_packet_ok(RADIUS_PACKET *packet, int flags)
 	 */
 	if ((hdr->code == 0) ||
 	    (hdr->code >= MAX_PACKET_CODE)) {
-		librad_log("WARNING: Bad RADIUS packet from host %s: unknown packet code %d",
+		librad_log("WARNING: Bad RADIUS packet from host %s: unknown packet code%d ",
 			   inet_ntop(packet->src_ipaddr.af,
 				     &packet->src_ipaddr.ipaddr,
 				     host_ipaddr, sizeof(host_ipaddr)),
@@ -1729,21 +1746,21 @@ RADIUS_PACKET *rad_recv(int fd, int flags)
 		char host_ipaddr[128];
 
 		if ((packet->code > 0) && (packet->code < MAX_PACKET_CODE)) {
-			printf("rad_recv: %s packet from host %s port %d",
-			       packet_codes[packet->code],
-			       inet_ntop(packet->src_ipaddr.af,
-					 &packet->src_ipaddr.ipaddr,
-					 host_ipaddr, sizeof(host_ipaddr)),
-			       packet->src_port);
+			DEBUG("rad_recv: %s packet from host %s port %d",
+			      packet_codes[packet->code],
+			      inet_ntop(packet->src_ipaddr.af,
+					&packet->src_ipaddr.ipaddr,
+					host_ipaddr, sizeof(host_ipaddr)),
+			      packet->src_port);
 		} else {
-			printf("rad_recv: Packet from host %s port %d code=%d",
-			       inet_ntop(packet->src_ipaddr.af,
-					 &packet->src_ipaddr.ipaddr,
-					 host_ipaddr, sizeof(host_ipaddr)),
-			       packet->src_port,
-			       packet->code);
+			DEBUG("rad_recv: Packet from host %s port %d code=%d",
+			      inet_ntop(packet->src_ipaddr.af,
+					&packet->src_ipaddr.ipaddr,
+					host_ipaddr, sizeof(host_ipaddr)),
+			      packet->src_port,
+			      packet->code);
 		}
-		printf(", id=%d, length=%d\n", packet->id, packet->data_len);
+		DEBUG(", id=%d, length=%d\n", packet->id, packet->data_len);
 	}
 
 	return packet;
@@ -1842,10 +1859,10 @@ int rad_verify(RADIUS_PACKET *packet, RADIUS_PACKET *original,
 	 *	It looks like a RADIUS packet, but we can't validate
 	 *	the signature.
 	 */
-	if ((packet->code == 0) || packet->code >= MAX_PACKET_CODE) {
+	if ((packet->code == 0) || (packet->code >= MAX_PACKET_CODE)) {
 		char buffer[32];
-		librad_log("Received Unknown packet code %d"
-			   "from client %s port %d: Cannot validate signature",
+		librad_log("Received Unknown packet code %d "
+			   "from client %s port %d: Cannot validate signature.",
 			   packet->code,
 			   inet_ntop(packet->src_ipaddr.af,
 				     &packet->src_ipaddr.ipaddr,
@@ -1863,17 +1880,19 @@ int rad_verify(RADIUS_PACKET *packet, RADIUS_PACKET *original,
 
 		case PW_AUTHENTICATION_REQUEST:
 		case PW_STATUS_SERVER:
-		case PW_DISCONNECT_REQUEST:
 			/*
 			 *	The authentication vector is random
 			 *	nonsense, invented by the client.
 			 */
 			break;
 
+		case PW_COA_REQUEST:
+		case PW_DISCONNECT_REQUEST:
 		case PW_ACCOUNTING_REQUEST:
 			if (calc_acctdigest(packet, secret) > 1) {
-				librad_log("Received Accounting-Request packet "
+				librad_log("Received %s packet "
 					   "from %s with invalid signature!  (Shared secret is incorrect.)",
+					   packet_codes[packet->code],
 					   inet_ntop(packet->src_ipaddr.af,
 						     &packet->src_ipaddr.ipaddr,
 						     buffer, sizeof(buffer)));
@@ -1905,7 +1924,7 @@ int rad_verify(RADIUS_PACKET *packet, RADIUS_PACKET *original,
 			break;
 
 		default:
-			librad_log("Received Unknown packet code %d"
+			librad_log("Received Unknown packet code %d "
 				   "from client %s port %d: Cannot validate signature",
 				   packet->code,
 				   inet_ntop(packet->src_ipaddr.af,
@@ -2907,7 +2926,7 @@ uint32_t fr_rand(void)
 	}
 
 	num = fr_rand_pool.randrsl[fr_rand_pool.randcnt++];
-	if (fr_rand_pool.randcnt == 256) {
+	if (fr_rand_pool.randcnt >= 256) {
 		fr_rand_pool.randcnt = 0;
 		fr_isaac(&fr_rand_pool);
 	}
